aboutsummaryrefslogtreecommitdiff
path: root/datapath/flow.h
diff options
context:
space:
mode:
authorJustin Pettit <jpettit@nicira.com>2010-12-29 19:03:46 -0800
committerJustin Pettit <jpettit@nicira.com>2011-02-02 12:53:26 -0800
commitd31f1109f10e5ffb9bf266306b913ebf23781666 (patch)
treeddd80cc2348874fdea55a4e88e0990f821fb5e03 /datapath/flow.h
parentbad68a9965215511b305c59d7f1830344ec2241f (diff)
nicira-ext: Support matching IPv6 traffic.
Provides ability to match over IPv6 traffic in the same manner as IPv4. Currently, the matching fields include: - IPv6 source and destination addresses (ipv6_src and ipv6_dst) - Traffic Class (nw_tos) - Next Header (nw_proto) - ICMPv6 Type and Code (icmp_type and icmp_code) - TCP and UDP Ports over IPv6 (tp_src and tp_dst) When defining IPv6 rules, the Nicira Extensible Match (NXM) extension to OVS must be used. Signed-off-by: Justin Pettit <jpettit@nicira.com> Acked-by: Ben Pfaff <blp@nicira.com>
Diffstat (limited to 'datapath/flow.h')
-rw-r--r--datapath/flow.h12
1 files changed, 10 insertions, 2 deletions
diff --git a/datapath/flow.h b/datapath/flow.h
index b9af2722..ee1c4c92 100644
--- a/datapath/flow.h
+++ b/datapath/flow.h
@@ -31,8 +31,16 @@ struct sw_flow_actions {
struct sw_flow_key {
__be64 tun_id; /* Encapsulating tunnel ID. */
- __be32 nw_src; /* IP source address. */
- __be32 nw_dst; /* IP destination address. */
+ union {
+ struct {
+ __be32 ipv4_src; /* IPv4 source address. */
+ __be32 ipv4_dst; /* IPv4 destination address. */
+ };
+ struct {
+ __be32 ipv6_src[4]; /* IPv6 source address. */
+ __be32 ipv6_dst[4]; /* IPv6 source address. */
+ };
+ };
u16 in_port; /* Input switch port. */
__be16 dl_tci; /* 0 if no VLAN, VLAN_TAG_PRESENT set otherwise. */
__be16 dl_type; /* Ethernet frame type. */